@@ -1,5 +1,5 @@
 """
- * $Id: 1.1+4 utils.py d9a751b54766 2021-05-28 od $
+ * $Id: 1.1+7 utils.py d15c914d73b4 2021-06-04 od $
  *
  * This file is part of the Cloud Services Integration Platform (CSIP),
  * a Model-as-a-Service framework, API and application suite.
@@ -68,7 +68,7 @@ class Client(object):
     # CONFIG defaults
     CONN_TIMEOUT = 2  # for "conn_timeout"
     READ_TIMEOUT = 10 # for "read_timeout"
-    RESP_TIMEOUT = 30 # for "resp_timeout"
+    SERVICE_TIMEOUT = 30 # for "service_timeout"
     RETRY = 3  # for "retry"
     ALLOW_REDIRECTS = True  # for "allow_redirects"
 
@@ -146,9 +146,9 @@ class Client(object):
     def __get0(url: str, conf: Dict):
         """HTTP GET to generate a Client"""
         conf = conf or {}
-        timeout = (conf.get('conn_timeout', Client.CONN_TIMEOUT), conf.get('read_timeout', Client.READ_TIMEOUT))
-        retry = conf.get('retry', Client.RETRY)
-        allow_redirects = conf.get('allow_redirects', Client.ALLOW_REDIRECTS)
+        timeout = (conf.get('http_conn_timeout', Client.CONN_TIMEOUT), conf.get('http_read_timeout', Client.READ_TIMEOUT))
+        retry = conf.get('http_retry', Client.RETRY)
+        allow_redirects = conf.get('http_allow_redirects', Client.ALLOW_REDIRECTS)
 
         http_status = 200
         response = None
@@ -182,12 +182,12 @@ class Client(object):
         """HTTP POST to generate a Client"""
         conf = conf or {}
         if sync:
-            timeout = (conf.get('conn_timeout', Client.CONN_TIMEOUT), conf.get('resp_timeout', Client.RESP_TIMEOUT))
+            timeout = (conf.get('http_conn_timeout', Client.CONN_TIMEOUT), conf.get('service_timeout', Client.SERVICE_TIMEOUT))
         else:
-            timeout = (conf.get('conn_timeout', Client.CONN_TIMEOUT), conf.get('read_timeout', Client.READ_TIMEOUT))
+            timeout = (conf.get('http_conn_timeout', Client.CONN_TIMEOUT), conf.get('http_read_timeout', Client.READ_TIMEOUT))
 
-        retry = conf.get('retry', Client.RETRY)
-        allow_redirects = conf.get('allow_redirects', Client.ALLOW_REDIRECTS)
+        retry = conf.get('http_retry', Client.RETRY)
+        allow_redirects = conf.get('http_allow_redirects', Client.ALLOW_REDIRECTS)
 
         http_status = 200
         response_json = None
@@ -355,7 +355,7 @@ class Client(object):
         # print(response_json)
         # print(http_status)
 
-        return Client(data, parent=self, metainfo=mi, http_status=http_status)
+        return Client(data, url=url, parent=self, metainfo=mi, http_status=http_status)
 
     def execute_async(self, url: str = None, files: List[str] = None,
                       first_poll: int = None, next_poll: int = None,
@@ -382,7 +382,8 @@ class Client(object):
         callback = callback or cb
 
         # calc expiration time
-        exp = int(time.time() * 1000.0) + int(conf.get('resp_timeout', Client.RESP_TIMEOUT) * 1000.0)
+        conf = conf or {}
+        exp = int(time.time() * 1000.0) + int(conf.get('service_timeout', Client.SERVICE_TIMEOUT) * 1000.0)
 
         # -> Submitted
         resp = self.execute(url, files=files, sync=False, headers=headers, conf=conf)
